@@ -53,8 +53,8 @@ impl APISecret for ConfigDiscord {}
 /*--                     --*/
 /*-------------------------*/
 /***************************/
+#[async_trait]
 impl<'a> SocialAPI<'a> for DiscordBox<'a> {
-    #[tokio::main]
     async fn send(&self, mut msg: String) -> Result<String> {
         msg.truncate(2000);
         let url = format!(
@@ -77,7 +77,6 @@ impl<'a> SocialAPI<'a> for DiscordBox<'a> {
         Ok(state_data)
     }
 
-    #[tokio::main]
     async fn get(&self, msgid: &str) -> Result<String> {
         let url = format!(
             "{}/{}/{}/messages/{}",
@@ -91,7 +90,6 @@ impl<'a> SocialAPI<'a> for DiscordBox<'a> {
         Ok(state_data)
     }
 
-    #[tokio::main]
     async fn delete(&self, msgid: &str) -> Result<String> {
         let url = format!(
             "{}/{}/{}/messages/{}",
@@ -104,6 +102,10 @@ impl<'a> SocialAPI<'a> for DiscordBox<'a> {
         let state_data: String = response.text().await?;
         Ok(state_data)
     }
+
+    async fn recv(&self) -> Result<String> {
+        unimplemented!()
+    }
 }
 /***************************/
 /*-------------------------*/
@@ -180,7 +182,7 @@ impl<'a> Publisher<'a> for DiscordAdapter<'a> {
             .await?;
         } else {
             let stored_message = stored_message?;
-            let message_resp = self.get_client().get(&stored_message.message_id)?;
+            let message_resp = self.get_client().get(&stored_message.message_id).await?;
             if message_resp.find("Unknown Message").is_some() {
                 delete_message(&self.get_conn(), MediaId::Discord, &stored_message).await?;
                 discord_publish(
@@ -215,7 +217,7 @@ async fn discord_publish<'e>(
     project: &Project,
     version: &Version,
 ) -> Result<()> {
-    let discord_response = client.send(DiscordBox::build(project, version))?;
+    let discord_response = client.send(DiscordBox::build(project, version)).await?;
     let message: DiscordMessage = serde_json::from_str(&discord_response)?;
     let sent_message = Message {
         media_id: MediaId::Discord,
