@@ -48,8 +48,8 @@ impl APISecret for ConfigTelegram {}
 /*--                     --*/
 /*-------------------------*/
 /***************************/
+#[async_trait]
 impl<'a> SocialAPI<'a> for TelegramBox<'a> {
-    #[tokio::main]
     async fn send(&self, mut msg: String) -> Result<String> {
         msg.truncate(4096);
         let request_url = format!(
@@ -64,7 +64,6 @@ impl<'a> SocialAPI<'a> for TelegramBox<'a> {
         Ok(state_data)
     }
 
-    #[tokio::main]
     async fn recv(&self) -> Result<String> {
         let request_url = format!(
             "{}/bot{}/getUpdates?offset={}",
@@ -77,7 +76,6 @@ impl<'a> SocialAPI<'a> for TelegramBox<'a> {
         Ok(message)
     }
 
-    #[tokio::main]
     async fn delete(&self, msgid: &str) -> Result<String> {
         let request_url = format!(
             "{}/bot{}/deleteMessage?chat_id={}&message_id={}",
@@ -90,6 +88,11 @@ impl<'a> SocialAPI<'a> for TelegramBox<'a> {
         let state_data: String = response.text().await?;
         Ok(state_data)
     }
+
+    async fn get(&self, msgid: &str) -> Result<String> {
+        drop(msgid);
+        unimplemented!()
+    }
 }
 
 /***************************/
@@ -167,17 +170,6 @@ impl<'a> Publisher<'a> for TelegramAdapter<'a> {
             .await?;
         } else {
             let stored_message = stored_message?;
-            // let message_resp = self.get_client().recv()?;
-            // if message_resp.find("Unknown Message").is_some() {
-            // delete_message(&self.get_conn(), MediaId::Telegram, &stored_message)?;
-            // telegram_publish(
-            // &self.get_conn(),
-            // &self.get_client(),
-            // &self.get_project(),
-            // &self.get_version(),
-            // )?;
-            // } else {
-            // let got_message: TelegramMessage = serde_json::from_str(&message_resp)?;
             let got_message_hash = &self.get_version().hash;
             if &stored_message.version_hash != got_message_hash {
                 telegram_publish(
@@ -188,7 +180,6 @@ impl<'a> Publisher<'a> for TelegramAdapter<'a> {
                 )
                 .await?;
             }
-            // println!("{:#?}", stored_message);
         }
         Ok(())
     }
@@ -200,7 +191,7 @@ async fn telegram_publish<'e>(
     project: &Project,
     version: &Version,
 ) -> Result<()> {
-    let telegram_response = client.send(TelegramBox::build(project, version))?;
+    let telegram_response = client.send(TelegramBox::build(project, version)).await?;
     let message: TelegramMessage = serde_json::from_str(&telegram_response)?;
     let sent_message = Message {
         media_id: MediaId::Telegram,
