@@ -66,30 +66,14 @@ impl<'a, T: APISecret> SocialBox<'a, T> {
     }
 }
 
+#[async_trait]
 pub trait SocialAPI<'a> {
     fn new<T: 'a + APISecret>(client: Client, api: &T) -> SocialBox<T> {
         SocialBox { client, api }
     }
 
-    #[tokio::main]
-    async fn send(&self, msg: String) -> Result<String> {
-        drop(msg);
-        unimplemented!()
-    }
-
-    #[tokio::main]
-    async fn recv(&self) -> Result<String> {
-        unimplemented!()
-    }
-    #[tokio::main]
-    async fn get(&self, msgid: &str) -> Result<String> {
-        drop(msgid);
-        unimplemented!()
-    }
-
-    #[tokio::main]
-    async fn delete(&self, msgid: &str) -> Result<String> {
-        drop(msgid);
-        unimplemented!()
-    }
+    async fn send(&self, msg: String) -> Result<String>;
+    async fn recv(&self) -> Result<String>;
+    async fn get(&self, msgid: &str) -> Result<String>;
+    async fn delete(&self, msgid: &str) -> Result<String>;
 }
