@@ -4,8 +4,8 @@ use sea_orm::entity::prelude::*;
 #[sea_orm(table_name = "branch")]
 pub struct Model {
     pub name: String,
-    #[sea_orm(primary_key)]
-    pub project_id: u32,
+    #[sea_orm(primary_key, unique, auto_increment = false)]
+    pub project_id: String,
 }
 
 #[derive(Copy, Clone, Debug, EnumIter, DeriveRelation)]
@@ -13,9 +13,9 @@ pub enum Relation {
     #[sea_orm(
         belongs_to = "super::project::Entity",
         from = "Column::ProjectId",
-        to = "super::project::Column::Id",
-        on_update = "NoAction",
-        on_delete = "NoAction"
+        to = "super::project::Column::Name",
+        on_update = "Cascade",
+        on_delete = "Cascade"
     )]
     Project,
 }
