@@ -4,7 +4,7 @@ use sea_orm::entity::prelude::*;
 #[sea_orm(table_name = "social_media")]
 pub struct Model {
     #[sea_orm(primary_key, auto_increment = false)]
-    pub id: u8,
+    pub id: i32,
     #[sea_orm(unique)]
     pub platform_name: String,
 }
