@@ -3,9 +3,10 @@ use sea_orm::entity::prelude::*;
 #[derive(Clone, Debug, PartialEq, DeriveEntityModel)]
 #[sea_orm(table_name = "tag")]
 pub struct Model {
+    #[sea_orm(primary_key)]
+    pub id: i32,
     pub name: String,
-    #[sea_orm(primary_key, auto_increment = false)]
-    pub project_id: u32,
+    pub project_id: String,
 }
 
 #[derive(Copy, Clone, Debug, EnumIter, DeriveRelation)]
@@ -13,9 +14,9 @@ pub enum Relation {
     #[sea_orm(
         belongs_to = "super::project::Entity",
         from = "Column::ProjectId",
-        to = "super::project::Column::Id",
-        on_update = "NoAction",
-        on_delete = "NoAction"
+        to = "super::project::Column::Name",
+        on_update = "Cascade",
+        on_delete = "Cascade"
     )]
     Project,
 }
