@@ -4,14 +4,14 @@ use sea_orm::entity::prelude::*;
 #[sea_orm(table_name = "version")]
 pub struct Model {
     #[sea_orm(primary_key)]
-    pub project_id: u32,
+    pub project_id: String,
     #[sea_orm(primary_key)]
     pub hash: String,
     pub timestamp: DateTimeUtc,
     pub name: String,
-    pub major: u8,
-    pub minor: u8,
-    pub patch: u8,
+    pub major: i32,
+    pub minor: i32,
+    pub patch: i32,
     pub codename: Option<String>,
     pub start_commit: Option<String>,
     pub end_commit: Option<String>,
@@ -23,16 +23,16 @@ pub enum Relation {
         belongs_to = "super::hash::Entity",
         from = "Column::Hash",
         to = "super::hash::Column::Id",
-        on_update = "NoAction",
-        on_delete = "NoAction"
+        on_update = "Cascade",
+        on_delete = "Cascade"
     )]
     Hash,
     #[sea_orm(
         belongs_to = "super::project::Entity",
         from = "Column::ProjectId",
-        to = "super::project::Column::Id",
-        on_update = "NoAction",
-        on_delete = "NoAction"
+        to = "super::project::Column::Name",
+        on_update = "Cascade",
+        on_delete = "Cascade"
     )]
     Project,
 }
