@@ -1,4 +1,5 @@
 mod api;
+mod cache;
 mod consts;
 mod core;
 mod db;
@@ -11,11 +12,12 @@ use crate::consts::{
     DEFAULT_CONFIG_DIR, DEFAULT_CONFIG_PATH, N3NX_ABOUT_PROJECT, N3NX_PROJECT_AUTHORS,
     N3NX_PROJECT_NAME, N3NX_PROJECT_VERSION, N3N_WOLF_LOGO, PROJECT_URL, WOLFIE_BANNER,
 };
-use clap::{App, Arg};
+use clap::{Arg, Command};
 use colored::*;
 use std::fs::{create_dir, read_to_string};
 
-fn main() -> Result<(), Box<dyn std::error::Error>> {
+#[tokio::main]
+async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let wolf_logo = N3N_WOLF_LOGO.truecolor(242, 175, 41);
     let wolfie_banner = WOLFIE_BANNER.truecolor(235, 248, 184);
     let project_version = N3NX_PROJECT_VERSION.white();
@@ -28,12 +30,12 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     println!("{} v{}\n", wolfie_banner, project_version);
     println!("{:13}{}", " ", PROJECT_URL);
 
-    let matches = App::new(project_name)
+    let matches = Command::new(project_name)
         .version(project_version_noncol)
         .author(project_authors)
         .about(about_project)
         .arg(
-            Arg::with_name("config")
+            Arg::new("config")
                 .help("Sets a config file to use")
                 .index(1),
         )
@@ -45,7 +47,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let raw_config = read_to_string(config)?;
     let config: Config = toml::from_str(&raw_config)?;
 
-    start_sync(&config)?;
+    start_sync(&config).await?;
 
     Ok(())
 }
